/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2022- Scandit AG. All rights reserved.
 */

#import <Foundation/Foundation.h>

#import <ScanditCaptureCore/SDCBase.h>
#import <ScanditCaptureCore/SDCControl.h>
#import <ScanditCaptureCore/SDCMeasureUnit.h>

typedef NS_CLOSED_ENUM(NSUInteger, SDCLinearControlGroupOrientation) {
    SDCLinearControlGroupOrientationVertical,
    SDCLinearControlGroupOrientationHorizontal
} NS_SWIFT_NAME(LinearControlGroupOrientation);

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(LinearControlGroup)
SDC_EXPORTED_SYMBOL
@interface SDCLinearControlGroup : NSObject <SDCControl>

+ (instancetype)new NS_UNAVAILABLE;
- (instancetype)init NS_UNAVAILABLE;

@property (nonatomic, nonnull, readonly) NSArray<id<SDCControl>> *controls;
@property (nonatomic, readonly) SDCLinearControlGroupOrientation orientation;
@property (nonatomic, readonly) SDCFloatWithUnit spacing;

+ (nullable instancetype)linearControlGroupFromJSONString:(nonnull NSString *)JSONString
                                                    error:(NSError *_Nullable *_Nullable)error;

- (instancetype)initWithControls:(NSArray<id<SDCControl>> *)controls;
- (instancetype)initWithControls:(NSArray<id<SDCControl>> *)controls
                     orientation:(SDCLinearControlGroupOrientation)orientation;
- (instancetype)initWithControls:(NSArray<id<SDCControl>> *)controls
                         spacing:(SDCFloatWithUnit)spacing;
- (instancetype)initWithControls:(NSArray<id<SDCControl>> *)controls
                     orientation:(SDCLinearControlGroupOrientation)orientation
                         spacing:(SDCFloatWithUnit)spacing NS_DESIGNATED_INITIALIZER;

@end

NS_ASSUME_NONNULL_END
